@@ -5,13 +5,14 @@ import (
 	"net/http"
 	"strings"
 
-	"github.com/jeessy2/ddns-go/v4/config"
+	"github.com/jeessy2/ddns-go/v5/config"
 )
 
 // WebhookTest 测试webhook
 func WebhookTest(writer http.ResponseWriter, request *http.Request) {
 	url := strings.TrimSpace(request.FormValue("URL"))
 	requestBody := strings.TrimSpace(request.FormValue("RequestBody"))
+	webhookHeaders := strings.TrimSpace(request.FormValue("WebhookHeaders"))
 
 	var domains = make([]*config.Domain, 1)
 	domains[0] = &config.Domain{}
@@ -30,6 +31,7 @@ func WebhookTest(writer http.ResponseWriter, request *http.Request) {
 		Webhook: config.Webhook{
 			WebhookURL:         url,
 			WebhookRequestBody: requestBody,
+			WebhookHeaders:     webhookHeaders,
 		},
 	}
 
